<?php


namespace App\Modules\OrangeSite\Services\CheckReport;


use App\Modules\OrangeSite\Services\OrangeSiteRechargeReportCheckContext;
use App\Modules\OrangeSite\Services\OrangeSiteReportRateService;
use Closure;
use Illuminate\Support\Facades\DB;
use Log;

class ReportRateCheck
{
    /**
     * @param $context OrangeSiteRechargeReportCheckContext
     * @param Closure $next
     * @return mixed
     */
    public function handle($context, Closure $next)
    {
        $currentRate = OrangeSiteReportRateService::getCurrentChannelReportRate($context->user->distribution_channel_id);
        $channelSettingRate = $context->reportInfo['configRate'];
        $context->reportInfo['reportRate'] = $currentRate;
        if ($currentRate <= $channelSettingRate) {
            Log::debug('[orangeSiteRechargeReport]订单通过比例', [
                'traceInfo' => $context->traceContext->getTraceInfo(),
                'channelSettingRate' => $channelSettingRate,
                'currentRate' => $currentRate]);
            return $next($context);
        } else {
            Log::debug('[orangeSiteRechargeReport]订单被比例过滤', [
                'traceInfo' => $context->traceContext->getTraceInfo(),
                'channelSettingRate' => $channelSettingRate,
                'currentRate' => $currentRate]);
            DB::transaction(function () use ($context, $channelSettingRate) {
                OrangeSiteReportRateService::increaseFailNum($context->user->distribution_channel_id, $channelSettingRate);
            });
            $context->result = [
                'result' => false,
                'firstReason' => 'ReportRateCheck',
                'type' => 'percent_filter',
                'content' => '比例过滤'
            ];
            return $context;
        }
    }
}